
'''
	import pathlib
	THIS_FOLDER = pathlib.Path (__file__).parent.resolve ()

	from os.path import dirname, join, normpath
	SEARCH = normpath (join (THIS_FOLDER, "../.."))

	import BODY_SCAN
	BODY_SCAN.START (
		GLOB 		= SEARCH + '/**/*STATUS.py'
	)
'''

import glob

from .FUNCTIONS.START_A_SCAN 			import START_A_SCAN

from .AGGREGATE import START as AGGREGATE_START

def START (
	GLOB = "",
	RELATIVE_PATH = False,
	
	MODULE_PATHS = [],
	
	RECORDS = 0	
):
	FINDS = glob.glob (GLOB, recursive = True)
		
	if (RECORDS >= 1):
		print ()
		print ("SEARCHING FOR GLOB:")
		print ("	", GLOB)
		print ()
	
	if (RECORDS >= 1):
		print ()
		print ("	FINDS:", FINDS)
		print ("	FINDS COUNT:", len (FINDS))
		print ();
	
	PATH_STATUSES = []
	for PATH in FINDS:	
		[ STATUS ] = START_A_SCAN (		
			PATH = PATH,
			MODULE_PATHS = MODULE_PATHS,
			RELATIVE_PATH = RELATIVE_PATH,
			RECORDS = RECORDS
		)
		
		PATH_STATUSES.append (STATUS)

	STATUS = AGGREGATE_START (
		PATH_STATUSES
	)

	import json
	print ("STATUS:", json.dumps (STATUS, indent = 4))
	
	
	
	return {
		"STATUS": STATUS
	}
	







def ADD_PATHS_TO_SYSTEM (PATHS):
	import pathlib
	FIELD = pathlib.Path (__file__).parent.resolve ()

	from os.path import dirname, join, normpath
	import sys
	for PATH in PATHS:
		sys.path.insert (0, normpath (join (FIELD, PATH)))



def CLIQUE ():
	import click
	@click.group ("KEG")
	def GROUP ():
		pass

	'''
		./STATUS_CHECK KEG OPEN \
		--port 10000
	'''
	@GROUP.command ("OPEN")
	@click.option ('--port', required = True)	
	@click.option ('--details', required = True)
	def OPEN (port, details):
		import json
		
		#print ("DETAILS:", details)
		#print (json.loads (details))
	
		DETAILS = json.loads (details)
		MODULE_PATHS = DETAILS ["MODULE_PATHS"];
	
		ADD_PATHS_TO_SYSTEM (MODULE_PATHS)
	
		from KEG import TAP as TAP_KEG
		
		TAP_KEG (
			PORT = port
		)

		return;


	return GROUP
	
def START_CLICK ():
	import click
	@click.group ()
	def GROUP ():
		pass
		
	GROUP.add_command (CLIQUE ())
	GROUP ()

START_CLICK ()



#
